@@ -18,10 +18,11 @@ from pandas import DataFrame
 from scipy.spatial import cKDTree
 from scipy.spatial.transform import Rotation
 
-from .. import Quantity, logger
-from .. import units as plonk_units
-from ..utils import norm
+from .._logging import logger
+from .._units import Quantity
+from .._units import units as plonk_units
 from ..utils.kernels import kernel_names, kernel_radius
+from ..utils.math import norm
 from .extra import extra_quantities
 
 
@@ -412,7 +413,7 @@ class Snap:
     def extra_quantities(self):
         """Make extra quantities available."""
         if self._extra_quantities:
-            raise ValueError('Extra quantities already available')
+            logger.info('Extra quantities already available')
         logger.debug(f'Loading extra quantities: {self.file_path.name}')
         extra_quantities(snap=self)
         self._extra_quantities = True
@@ -483,9 +484,7 @@ class Snap:
         Snap
         """
         if self._physical_units:
-            raise ValueError(
-                'Physical units already set: snap.unset(units=True) to unset.'
-            )
+            logger.info('Physical units already set: snap.unset(units=True) to unset.')
         logger.debug(f'Setting physical units: {self.file_path.name}')
         for arr in self.loaded_arrays():
             self._arrays[arr] = self._arrays[arr] * self.get_array_unit(arr)
@@ -1207,27 +1206,6 @@ class SubSnap(Snap):
 SnapLike = Union[Snap, SubSnap]
 
 
-def get_array_in_code_units(snap: SnapLike, name: str) -> ndarray:
-    """Get array in code units.
-
-    Parameters
-    ----------
-    snap
-        The Snap or SubSnap.
-    name
-        The array name.
-
-    Returns
-    -------
-    ndarray
-        The array on the particles in code units.
-    """
-    arr = snap[name]
-    if isinstance(arr, Quantity):
-        return (arr / snap.get_array_unit(name)).magnitude
-    return arr
-
-
 def _str_is_int(string):
     try:
         int(string)
